@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2002-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2002-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -23,20 +23,11 @@
 
 // kde includes
 #include <KColorButton>
-#if QT_VERSION < 0x050000
-#include <kfontchooser.h>
-#include <KIntSpinBox>
-#endif
 
 // qt includes
 #include <QCheckBox>
-#if QT_VERSION >= 0x050000
 #include <QFontDialog>
-#endif
 #include <QGroupBox>
-#if QT_VERSION >= 0x050000
-#include <QSpinBox>
-#endif
 
 SettingsDialog::SettingsDialog(QWidget * parent, Settings::OptionState *state)
   : MultiPageDialogBase(parent, true)
@@ -175,11 +166,7 @@ void SettingsDialog::slotOk()
     applyPage(pageFont);
     applyPage(pageAutoLayout);
     m_pOptionState->save();
-#if QT_VERSION >= 0x050000
     UmbrelloSettings::self()->save();
-#else
-    UmbrelloSettings::self()->writeConfig();
-#endif
     accept();
 }
 
