@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2002-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2002-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header file
@@ -82,7 +82,7 @@ void ActorWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem *optio
  */
 void ActorWidget::saveToXMI(QXmlStreamWriter& writer)
 {
-    writer.writeStartElement(QLatin1String("actorwidget"));
+    writer.writeStartElement(QStringLiteral("actorwidget"));
     UMLWidget::saveToXMI(writer);
     writer.writeEndElement();
 }
