@@ -16,9 +16,6 @@
 
 // kde include files
 #include <KLocalizedString>
-#if QT_VERSION < 0x050000
-#include <KAction>
-#endif
 #include <KActionCollection>
 
 // qt include files
@@ -30,7 +27,7 @@
  * @param parentWindow      The parent of the toolbar.
  */
 WorkToolBar::WorkToolBar(QMainWindow *parentWindow)
-  : KToolBar(QLatin1String("worktoolbar"), parentWindow, Qt::TopToolBarArea, true, true, true)
+  : KToolBar(QStringLiteral("worktoolbar"), parentWindow, Qt::TopToolBarArea, true, true, true)
 {
     m_CurrentButtonID = tbb_Undefined;
     loadPixmaps();
@@ -65,11 +62,7 @@ WorkToolBar::~WorkToolBar()
  */
 QAction* WorkToolBar::insertHotBtn(ToolBar_Buttons tbb)
 {
-#if QT_VERSION >= 0x050000
     QAction *action = m_actions[tbb];
-#else
-    KAction *action = m_actions[tbb];
-#endif
     addAction(action);
     action->setCheckable(true);
     return action;
@@ -402,13 +395,8 @@ void WorkToolBar::loadPixmaps()
     for (uint i = 0; i < n_buttonInfos; ++i) {
         const ButtonInfo& info = buttonInfo[i];
         QString key = QLatin1String(ENUM_NAME(WorkToolBar, ToolBar_Buttons, info.tbb));
-#if QT_VERSION >= 0x050000
         QAction *action = collection->addAction(key, this, info.slotName);
         action->setIcon(Icon_Utils::BarIcon(info.icon));
-#else
-        KAction *action = collection->addAction(key, this, info.slotName);
-        action->setIcon(KIcon(Icon_Utils::BarIcon(info.icon)));
-#endif
         action->setText(info.btnName);
         m_actions[info.tbb] = action;
         m_cursors[info.tbb] = Icon_Utils::Cursor(info.icon);
@@ -498,8 +486,8 @@ void WorkToolBar::setupActions()
 {
     foreach(QAction *action, m_actions) {
         if (!action->shortcut().isEmpty()) {
-            action->setToolTip(action->text() + QLatin1String("\t[") +
-                               action->shortcut().toString() + QLatin1String("]"));
+            action->setToolTip(action->text() + QStringLiteral("\t[") +
+                               action->shortcut().toString() + QStringLiteral("]"));
         }
         else
             action->setToolTip(action->text());
